@@ -10,11 +10,12 @@
 use strict;
 package CPAN::Reporter::Config;
 BEGIN {
-  $CPAN::Reporter::Config::VERSION = '1.19_03';
+  $CPAN::Reporter::Config::VERSION = '1.19_04';
 }
 # ABSTRACT: Config file options for CPAN::Reporter
 
 use Config::Tiny 2.08 ();
+use File::Glob ();
 use File::HomeDir 0.58 ();
 use File::Path qw/mkpath/;
 use File::Spec 3.19 ();
@@ -125,7 +126,7 @@ sub _configure {
                 )
             )) {
                 if  ( ! $option_data->{validate} ||
-                        $option_data->{validate}->($k, $answer)
+                        $option_data->{validate}->($k, $answer, $config->{_})
                     ) {
                     $config->{_}{$k} = $answer;
                     last PROMPT;
@@ -314,18 +315,36 @@ sub _config_spec { return %option_specs }
 #--------------------------------------------------------------------------#
 
 sub _generate_profile {
-    my ($id_file) = @_;
+    my ($id_file, $config) = @_;
 
     my $cmd = IPC::Cmd::can_run('metabase-profile');
-    if ( $cmd ) {
-        return scalar IPC::Cmd::run(
-            command => [$cmd, "--output", $id_file],
-            verbose => 1,
-        );
+    return unless $cmd;
+
+    # XXX this is an evil assumption about email addresses, but
+    # might do for simple cases that users might actually provide
+
+    my @opts = ("--output" => $id_file);
+    my $email = $config->{email_from};
+
+    if ($email =~ /\A(.+)\s+<([^>]+)>\z/ ) {
+        push @opts, "--email"   => $2;
+        my $name = $1;
+        $name =~ s/\A["'](.*)["']\z/$1/;
+        push ( @opts, "--name"    => $1)
+            if length $name;
     }
     else {
-        return 0;
+        push @opts, "--email"   => $email;
     }
+
+    # XXX profile 'secret' is really just a generated API key, so we
+    # can create something fairly random for the user and use that
+    push @opts, "--secret"      => sprintf("%08x", rand(2**31));
+
+    return scalar IPC::Cmd::run(
+        command => [ $cmd, @opts ],
+        verbose => 1,
+    );
 }
 
 #--------------------------------------------------------------------------#
@@ -437,6 +456,25 @@ sub _is_valid_grade {
     return grep { $grade eq $_ } @valid_grades;
 }
 
+
+#--------------------------------------------------------------------------#
+# _normalize_id_file
+#--------------------------------------------------------------------------#
+
+sub _normalize_id_file {
+    my ($id_file) = @_;
+
+    if ( $id_file =~ /~/ ) {
+        $id_file = File::Glob::bsd_glob( $id_file );
+    }
+    unless ( File::Spec->file_name_is_absolute( $id_file ) ) {
+        $id_file = File::Spec->catfile(
+            CPAN::Reporter::Config::_get_config_dir(), $id_file
+        );
+    }
+    return $id_file;
+}
+
 #--------------------------------------------------------------------------#
 # _open_config_file
 #--------------------------------------------------------------------------#
@@ -530,7 +568,7 @@ sub _validate_grade_action_pair {
 }
 
 sub _validate_transport {
-    my ($name, $option) = @_;
+    my ($name, $option, $config) = @_;
     my $transport = '';
 
     if ( $option =~ /^(\w+)\s?/ ) {
@@ -566,18 +604,15 @@ sub _validate_transport {
             return;
         }
 
-        my $id_file = $1;
-        unless ( File::Spec->file_name_is_absolute( $id_file ) ) {
-            $id_file = File::Spec->catfile(_get_config_dir(), $id_file);
-        }
+        my $id_file = _normalize_id_file($1);
 
         # Offer to create if it doesn't exist
         if ( ! -e $id_file )  {
             my $answer = CPAN::Shell::colorable_makemaker_prompt(
-                "Would you like to run 'metabase-profile' now to create '$id_file'?", "y"
+                "\nWould you like to run 'metabase-profile' now to create '$id_file'?", "y"
             );
             if ( $answer =~ /^y/i ) {
-                return _generate_profile( $id_file );
+                return _generate_profile( $id_file, $config );
             }
             else {
                 $CPAN::Frontend->mywarn( <<"END_ID_FILE" );
@@ -631,7 +666,7 @@ CPAN::Reporter::Config - Config file options for CPAN::Reporter
 
 =head1 VERSION
 
-version 1.19_03
+version 1.19_04
 
 =head1 SYNOPSIS
 
